==> opennms-detector-jmx-19.0.0-20160712.110227-97-sources.jar: org/opennms/netmgt/provision/detector/jmx/JBossDetector.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2007-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.provision.detector.jmx;

import com.google.common.collect.ImmutableMap;

import org.opennms.netmgt.jmx.connection.JmxServerConnectionWrapper;
import org.opennms.netmgt.provision.support.jmx.connectors.JBossConnectionFactory;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Component;

import java.net.InetAddress;

@Component
/**
 * <p>JBossDetector class.</p>
 *
 * @author ranger
 * @version $Id: $
 */
@Scope("prototype")
public class JBossDetector extends JMXDetector {
    
    private static String DEFAULT_SERVICE_NAME = "JBoss";
    private static int DEFAULT_JBOSS_PORT = 1099;
    
    /**
     * <p>Constructor for JBossDetector.</p>
     */
    public JBossDetector() {
        super(DEFAULT_SERVICE_NAME, DEFAULT_JBOSS_PORT);
    }

    /** {@inheritDoc} */
    @Override
    protected JmxServerConnectionWrapper connect(final InetAddress address, final int port, final int timeout) {
        return JBossConnectionFactory.getMBeanServerConnection(ImmutableMap.<String, Object>builder()
                                                                           .put("port", port)
                                                                           .put("timeout", timeout)
                                                                           .build(),
                                                               address);
    }
}

==> opennms-detector-jmx-19.0.0-20200425.022740-368-sources.jar: org/opennms/netmgt/provision/detector/jmx/JBossDetector.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2007-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.provision.detector.jmx;

import com.google.common.collect.ImmutableMap;

import org.opennms.netmgt.jmx.connection.JmxServerConnectionWrapper;
import org.opennms.netmgt.provision.support.jmx.connectors.JBossConnectionFactory;
import java.net.InetAddress;
import java.util.Map;


/**
 * <p>JBossDetector class.</p>
 *
 * @author ranger
 * @version $Id: $
 */

public class JBossDetector extends JMXDetector {
    
    private static String DEFAULT_SERVICE_NAME = "JBoss";
    private static int DEFAULT_JBOSS_PORT = 1099;
    
    /**
     * <p>Constructor for JBossDetector.</p>
     */
    public JBossDetector() {
        super(DEFAULT_SERVICE_NAME, DEFAULT_JBOSS_PORT);
    }

    /** {@inheritDoc} */
    @Override
    protected JmxServerConnectionWrapper connect(final InetAddress address, final int port, final int timeout, final Map<String, String> runtimeAttributes) {
        return JBossConnectionFactory.getMBeanServerConnection(ImmutableMap.<String, Object>builder()
                                                                           .put("port", port)
                                                                           .put("timeout", timeout)
                                                                           .build(),
                                                               address);
    }
}
